@@ -7,7 +7,7 @@ use strict;
 use integer;
 
 use vars qw( $VERSION @ISA @EXPORT @EXPORT_OK );
-$VERSION   = '1.16';
+$VERSION   = '1.19';
 
 @ISA       = qw( Exporter );
 @EXPORT    = qw( timegm timelocal );
@@ -29,17 +29,17 @@ use constant SECS_PER_MINUTE => 60;
 use constant SECS_PER_HOUR   => 3600;
 use constant SECS_PER_DAY    => 86400;
 
-my $MaxInt = ( ( 1 << ( 8 * $Config{intsize} - 2 ) ) -1 ) * 2 + 1;
-my $MaxDay = int( ( $MaxInt - ( SECS_PER_DAY / 2 ) ) / SECS_PER_DAY ) - 1;
-
+my $MaxInt;
 if ( $^O eq 'MacOS' ) {
     # time_t is unsigned...
-    $MaxInt = ( 1 << ( 8 * $Config{intsize} ) ) - 1;
+    $MaxInt = ( 1 << ( 8 * $Config{ivsize} ) ) - 1;
 }
 else {
-    $MaxInt = ( ( 1 << ( 8 * $Config{intsize} - 2 ) ) - 1 ) * 2 + 1;
+    $MaxInt = ( ( 1 << ( 8 * $Config{ivsize} - 2 ) ) - 1 ) * 2 + 1;
 }
 
+my $MaxDay = int( ( $MaxInt - ( SECS_PER_DAY / 2 ) ) / SECS_PER_DAY ) - 1;
+
 # Determine the EPOC day for this machine
 my $Epoc = 0;
 if ( $^O eq 'vos' ) {
@@ -68,7 +68,7 @@ sub _daygm {
     return $_[3] + (
         $Cheat{ pack( 'ss', @_[ 4, 5 ] ) } ||= do {
             my $month = ( $_[4] + 10 ) % 12;
-            my $year  = $_[5] + 1900 - $month / 10;
+            my $year  = ( $_[5] + 1900 ) - ( $month / 10 );
 
             ( ( 365 * $year )
               + ( $year / 4 )
@@ -99,12 +99,6 @@ sub timegm {
     }
 
     unless ( $Options{no_range_check} ) {
-        if ( abs($year) >= 0x7fff ) {
-            $year += 1900;
-            croak
-                "Cannot handle date ($sec, $min, $hour, $mday, $month, *$year*)";
-        }
-
         croak "Month '$month' out of range 0..11"
             if $month > 11
             or $month < 0;
@@ -222,12 +216,16 @@ C<localtime()> and C<gmtime()>.
 
 =head1 FUNCTIONS
 
+=head2 C<timelocal()> and C<timegm()>
+
 This module exports two functions by default, C<timelocal()> and
 C<timegm()>.
 
 The C<timelocal()> and C<timegm()> functions perform range checking on
 the input $sec, $min, $hour, $mday, and $mon values by default.
 
+=head2 C<timelocal_nocheck()> and C<timegm_nocheck()>
+
 If you are working with data you know to be valid, you can speed your
 code up by using the "nocheck" variants, C<timelocal_nocheck()> and
 C<timegm_nocheck()>. These variants must be explicitly imported.
@@ -350,6 +348,15 @@ Please submit bugs to the CPAN RT system at
 http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Time-Local or via email
 at bug-time-local@rt.cpan.org.
 
+=head1 COPYRIGHT
+
+Copyright (c) 1997-2003 Graham Barr, 2003-2007 David Rolsky.  All
+rights reserved.  This program is free software; you can redistribute
+it and/or modify it under the same terms as Perl itself.
+
+The full text of the license can be found in the LICENSE file included
+with this module.
+
 =head1 AUTHOR
 
 This module is based on a Perl 4 library, timelocal.pl, that was
